@@ -316,7 +316,6 @@ fn set_style<A, B>(style: &CssStyleDeclaration, name: &A, value: B, important: b
 
         bindings::set_style(style, name, value, important);
 
-        // TODO maybe use cfg(debug_assertions) ?
         let is_changed = bindings::get_style(style, name) != "";
 
         if is_changed {
@@ -339,8 +338,10 @@ fn set_style<A, B>(style: &CssStyleDeclaration, name: &A, value: B, important: b
     });
 
     if let None = okay {
-        // TODO maybe make this configurable
-        panic!("style is incorrect:\n  names: {}\n  values: {}", names.join(", "), values.join(", "));
+        if cfg!(debug_assertions) {
+            // TODO maybe make this configurable
+            panic!("style is incorrect:\n  names: {}\n  values: {}", names.join(", "), values.join(", "));
+        }
     }
 }
 
@@ -367,6 +368,33 @@ fn set_style_signal<A, B, C, D>(style: CssStyleDeclaration, callbacks: &mut Call
     });
 }
 
+// TODO should this inline ?
+fn set_style_unchecked_signal<A, B, C, D>(style: CssStyleDeclaration, callbacks: &mut Callbacks, name: A, value: D, important: bool)
+    where A: AsStr + 'static,
+          B: AsStr,
+          C: OptionStr<Output = B>,
+          D: Signal<Item = C> + 'static {
+
+    set_option(style, callbacks, value, move |style, value| {
+        match value {
+            Some(value) => {
+                name.with_str(|name| {
+                    let name: &str = intern(name);
+
+                    value.with_str(|value| {
+                        bindings::set_style(style, name, value, important);
+                    });
+                });
+            },
+            None => {
+                name.with_str(|name| {
+                    bindings::remove_style(style, intern(name));
+                });
+            },
+        }
+    });
+}
+
 // TODO check that the property *actually* was changed ?
 // TODO maybe use AsRef<Object> ?
 // TODO should this inline ?
@@ -457,7 +485,7 @@ impl<A> DomBuilder<A> {
 
     #[inline]
     pub fn apply<F>(self, f: F) -> Self where F: FnOnce(Self) -> Self {
-        self.apply_if(true, f)
+        f(self)
     }
 
     #[inline]
@@ -485,6 +513,7 @@ impl<A> DomBuilder<A> where A: Clone {
         f(self, element)
     }
 
+    #[deprecated(since = "0.5.20", note = "Use the with_node macro instead")]
     #[inline]
     pub fn before_inserted<F>(self, f: F) -> Self where F: FnOnce(A) {
         let element = self.element.clone();
@@ -904,6 +933,18 @@ impl<A> DomBuilder<A> where A: AsRef<HtmlElement> {
         set_style(&self.element.as_ref().style(), &name, value, true);
         self
     }
+
+    #[inline]
+    pub fn style_unchecked<B, C>(self, name: B, value: C) -> Self
+        where B: AsStr,
+              C: AsStr {
+        name.with_str(|name| {
+            value.with_str(|value| {
+                bindings::set_style(&self.element.as_ref().style(), intern(name), value, false);
+            });
+        });
+        self
+    }
 }
 
 impl<A> DomBuilder<A> where A: AsRef<HtmlElement> {
@@ -929,6 +970,17 @@ impl<A> DomBuilder<A> where A: AsRef<HtmlElement> {
         self
     }
 
+    #[inline]
+    pub fn style_unchecked_signal<B, C, D, E>(mut self, name: B, value: E) -> Self
+        where B: AsStr + 'static,
+              C: AsStr,
+              D: OptionStr<Output = C>,
+              E: Signal<Item = D> + 'static {
+
+        set_style_unchecked_signal(self.element.as_ref().style(), &mut self.callbacks, name, value, false);
+        self
+    }
+
 
     // TODO remove the `value` argument ?
     #[inline]
@@ -1049,6 +1101,18 @@ impl StylesheetBuilder {
         self
     }
 
+    #[inline]
+    pub fn style_unchecked<B, C>(self, name: B, value: C) -> Self
+        where B: AsStr,
+              C: AsStr {
+        name.with_str(|name| {
+            value.with_str(|value| {
+                bindings::set_style(&self.element, intern(name), value, false);
+            });
+        });
+        self
+    }
+
     #[inline]
     pub fn style_signal<B, C, D, E>(mut self, name: B, value: E) -> Self
         where B: MultiStr + 'static,
@@ -1071,6 +1135,17 @@ impl StylesheetBuilder {
         self
     }
 
+    #[inline]
+    pub fn style_unchecked_signal<B, C, D, E>(mut self, name: B, value: E) -> Self
+        where B: AsStr + 'static,
+              C: AsStr,
+              D: OptionStr<Output = C>,
+              E: Signal<Item = D> + 'static {
+
+        set_style_unchecked_signal(self.element.clone(), &mut self.callbacks, name, value, false);
+        self
+    }
+
     // TODO return a Handle
     #[inline]
     #[doc(hidden)]
@@ -1125,6 +1200,14 @@ impl ClassBuilder {
         self
     }
 
+    #[inline]
+    pub fn style_unchecked<B, C>(mut self, name: B, value: C) -> Self
+        where B: AsStr,
+              C: AsStr {
+        self.stylesheet = self.stylesheet.style_unchecked(name, value);
+        self
+    }
+
     #[inline]
     pub fn style_signal<B, C, D, E>(mut self, name: B, value: E) -> Self
         where B: MultiStr + 'static,
@@ -1147,6 +1230,17 @@ impl ClassBuilder {
         self
     }
 
+    #[inline]
+    pub fn style_unchecked_signal<B, C, D, E>(mut self, name: B, value: E) -> Self
+        where B: AsStr + 'static,
+              C: AsStr,
+              D: OptionStr<Output = C>,
+              E: Signal<Item = D> + 'static {
+
+        self.stylesheet = self.stylesheet.style_unchecked_signal(name, value);
+        self
+    }
+
     // TODO return a Handle ?
     #[doc(hidden)]
     #[inline]
