@@ -57,6 +57,10 @@ macro_rules! make_event {
         impl $name {
             #[inline] pub fn prevent_default(&self) { self.event.prevent_default(); }
 
+            #[inline] pub fn stop_propagation(&self) { self.event.stop_propagation(); }
+
+            #[inline] pub fn stop_immediate_propagation(&self) { self.event.stop_immediate_propagation(); }
+
             #[inline] pub fn target(&self) -> Option<EventTarget> { self.event.target() }
 
             #[inline]
@@ -67,7 +71,7 @@ macro_rules! make_event {
     };
 }
 
-#[derive(Debug, Clone, Copy)]
+#[derive(Debug, Clone, Copy, Eq, PartialEq, Hash)]
 pub enum MouseButton {
     Left,
     Middle,
@@ -120,6 +124,7 @@ macro_rules! make_keyboard_event {
             #[inline] pub fn ctrl_key(&self) -> bool { self.event.ctrl_key() || self.event.meta_key() }
             #[inline] pub fn shift_key(&self) -> bool { self.event.shift_key() }
             #[inline] pub fn alt_key(&self) -> bool { self.event.alt_key() }
+            #[inline] pub fn repeat(&self) -> bool { self.event.repeat() }
         }
     };
 }
